@@ -4,7 +4,7 @@
 # imports.
 from syst3m.classes.config import version
 from syst3m.classes import utils, console, objects, browser, cache
-from syst3m.classes.system import User, Group
+from syst3m.classes.system import User, Group, check_user, check_group
 from syst3m.classes.color import color, symbol
 from syst3m.classes import defaults
 from syst3m.classes.env import env
