@@ -67,21 +67,14 @@ def execute(
 				self.str = self["output"]
 			else:
 				self.str = self.error
+		def __len__(self):
+			return len(self.str)
 		def __str__(self):
 			return str(self.str)
 		# support default iteration.
 		def __iter__(self):
 			return iter(str(self))
 		# support '==' & '!=' operator.
-		def __eq__(self, string):
-			if not isinstance(string, str):
-				return False
-			return self.str == string
-		def __ne__(self, string):
-			if not isinstance(string, str):
-				return True
-			return self.str != string
-		# support '==' & '!=' operator.
 		def __eq__(self, dictionary):
 			if isinstance(dictionary, str):
 				return self.str == dictionary
