@@ -51,19 +51,19 @@ def alias(
 	l_alias = cl1.get_argument("--create-alias", required=False)
 	present = "--create-alias" in sys.argv and l_alias == alias
 	base = f"/usr/local/bin"
-	if not os.path.exists(base):
+	if not Files.exists(base):
 		base = f"/usr/bin/"
 	path = f"{base}/{alias}"
-	if ((cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite) and present) or (present or not os.path.exists(path)):
+	if ((cl1.argument_present("--force") or cl1.argument_present("--forced") or overwrite) and present) or (present or not Files.exists(path)):
 		if l_alias != None: alias = l_alias
 		#file = f"""package={executable}/\nargs=""\nfor var in "$@" ; do\n   	if [ "$args" == "" ] ; then\n   		args=$var\n   	else\n   		args=$args" "$var\n   	fi\ndone\npython3 $package $args\n"""
-		sudo = Formats.Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
+		sudo = Boolean("--sudo" in sys.argv).convert(true="sudo ",false="")
 		file = f"""#!/usr/bin/env python3\nimport os, sys\npackage="{executable}"\nsys.argv.pop(0)\narguments = sys.argv\ns = ""\nfor i in arguments:\n	if s == "": \n		if " " in i: s = "'"+i+"'"\n		else: s = i\n	else: \n		if " " in i: s += " '"+i+"'"\n		else: s += " "+i\nif os.path.exists("/usr/bin/python3"): os.system("/usr/bin/python3 "+package+" "+s)\nelse:  os.system("python3 "+package+" "+s)"""
 		os.system(f"{sudo}touch {path}")
 		os.system(f"{sudo}chmod +x {path}")
 		os.system(f"{sudo}chown {vars.user}:{vars.group} {path}")
 		try:
-			Files.File(path=f"{path}", data=file).save()
+			File(path=f"{path}", data=file).save()
 		except:
 			print(f"Unable to create alias $ {alias}.")
 			return None
@@ -76,7 +76,7 @@ def alias(
 
 # get source path.
 def source_path(path, back=1):
-	return Formats.FilePath(path).base(back=back)
+	return FilePath(path).base(back=back)
 
 # get log level.
 def log_level(default=0):
@@ -84,7 +84,7 @@ def log_level(default=0):
 
 # get current working directory.
 def pwd():
-	return Formats.FilePath(utils.__execute_script__("pwd").replace("\n","")).clean()
+	return FilePath(utils.__execute_script__("pwd").replace("\n","")).clean()
 
 # kill pids.
 def kill(
@@ -122,7 +122,7 @@ def kill(
 			loader_ = console.Loader(f"Killing process {pid}.")
 		else:
 			log_level = -1
-		_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
+		_sudo_ = Boolean(sudo).convert(true="sudo ", false="")
 		output = utils.__execute_script__(f"{_sudo_}kill {pid}")
 		if output in ["terminated",""]:
 			if output in [""]:
@@ -146,7 +146,7 @@ def processes(
 	# all processes that include a str.
 	includes=None,
 ):
-	_sudo_ = Formats.Boolean(sudo).convert(true="sudo ", false="")
+	_sudo_ = Boolean(sudo).convert(true="sudo ", false="")
 	if isinstance(includes, str):
 		command = f"""{_sudo_}ps -ax | grep "{includes}" | """
 	else:
@@ -167,5 +167,4 @@ def processes(
 		"processes":processes,
 	})
 
-
 #
\ No newline at end of file
